@@ -1,7 +1,7 @@
 use warnings;
 use strict;
 
-package Text::Parser 0.800;
+package Text::Parser 0.801;
 
 # ABSTRACT: Bare text parser, bundles many common "mundane" tasks.
 
@@ -55,10 +55,6 @@ use Scalar::Util 'openhandle';
 use Role::Tiny;
 
 
-my (%allowed_options)
-    = ( auto_chomp => '0|1', multiline_type => 'join_next|join_last' );
-my (%default_values) = ( auto_chomp => 0, multiline_type => undef );
-
 sub new {
     my $pkg = shift;
     return undef if not __check_options(@_);
@@ -67,12 +63,9 @@ sub new {
     return $obj->__return_my_object();
 }
 
-sub __return_my_object {
-    my $obj = shift;
-    return $obj if not defined $obj->setting('multiline_type');
-    Role::Tiny->apply_roles_to_object( $obj, 'Text::Parser::Multiline' );
-    return $obj;
-}
+my (%allowed_options)
+    = ( auto_chomp => '0|1', multiline_type => 'join_next|join_last' );
+my (%default_values) = ( auto_chomp => 0, multiline_type => undef );
 
 sub __check_options {
     my (%opt) = @_;
@@ -92,6 +85,13 @@ sub __set_options {
     return \%opt;
 }
 
+sub __return_my_object {
+    my $obj = shift;
+    return $obj if not defined $obj->setting('multiline_type');
+    Role::Tiny->apply_roles_to_object( $obj, 'Text::Parser::Multiline' );
+    return $obj;
+}
+
 
 sub setting {
     my ( $self, $key ) = ( shift, shift );
@@ -309,7 +309,7 @@ Text::Parser - Bare text parser, bundles many common "mundane" tasks.
 
 =head1 VERSION
 
-version 0.800
+version 0.801
 
 =head1 SYNOPSIS
 
@@ -380,6 +380,24 @@ The options have the following interpretation:
      multiline_type => 'join_last' : Multi-line parser, that continues previous line in the current line
                     => undef (Default)
 
+=head3 Which C<multiline_type> is right for me?
+
+If your text format allows users to break up their text into another line while indicating a continuation, you need to use the C<multiline_type> option. The option allows you to join those lines back into a single line, so that your C<save_record> method doesn't have to bother about joining the continued lines, stripping any continuation characters, line-feeds etc. If your text format does not allow users to break up information into multiple lines like that, then this is not what you want.
+
+If you need to write a multi-line parser, then you need to set C<multiline_type> option to one of the values shown above. How do you decide which one?
+
+=over 4
+
+=item *
+
+If your format allows something like a trailing back-slash or some other character to indicate that text on I<B<next>> line is to be joined with this one, then choose C<join_next>.
+
+=item *
+
+If your format allows some character to indicate that text on the current line is part of the I<B<last>> line, then choose C<join_last>.
+
+=back
+
 =head2 setting
 
 Takes a single string as argument, and returns the value of that setting. The string must be one of:
@@ -657,20 +675,14 @@ Below is a trivial example where all lines are joined into one:
 
     use strict;
     use warnings;
-    package JoinAllLines;
-    use parent 'Text::Parser';
+    use Text::Parser;
 
-    sub new {
-        $pkg = shift;
-        $pkg->SUPER::new(auto_chomp => 1, multiline_type => 'join_last');
-    }
-
-    package main;
-
-    my $join_all = JoinAllLines->new();
+    my $join_all = Text::Parser->new(auto_chomp => 1, multiline_type => 'join_last');
     $join_all->read('input.txt');
     print $join_all->get_records(), "\n";
 
+Another trivial example is L<here|Text::Parser::Multiline/SYNOPSIS>.
+
 =head3 Continue with character
 
 (Pun intended! ;-))
@@ -725,7 +737,7 @@ When you run the above code with this file, you should get:
     Read:
     Garbage In. Garbage Out!
 
-=head3 Continuing from previous line
+=head3 Simple SPICE line joiner
 
 Some text formats allow a line to indicate that it is continuing from a previous line. For example L<SPICE|https://bwrcs.eecs.berkeley.edu/Classes/IcBook/SPICE/> has a continuation character (C<+>) on the next line, indicating that the text on that line should be joined with the I<previous> line. Let's show how to build a simple SPICE line-joiner. To build a full-fledged parser you will have to specify the rich and complex grammar for SPICE circuit description.
 
@@ -762,13 +774,12 @@ Some text formats allow a line to indicate that it is continuing from a previous
         $self->SUPER::save_record($line);
     }
 
-Try this parser with a simple SPICE deck and see what you get.
+Try this parser with a simple SPICE deck and see what you get. You may now write a more elaborate method for C<save_record> above and that could be used to parse a full SPICE file.
 
 =head1 BUGS
 
 Please report any bugs or feature requests on the bugtracker website
-L<http://rt.cpan.org/Public/Dist/Display.html?Name=Text-Parser> or by email
-to L<bug-text-parser at rt.cpan.org|mailto:bug-text-parser at rt.cpan.org>.
+L<http://github.com/me/Text-Parser/issues>
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
