@@ -1,7 +1,7 @@
 use strict;
 use warnings;
 
-package Text::Parser::Multiline 0.800;
+package Text::Parser::Multiline 0.801;
 
 # ABSTRACT: Adds multi-line support to the Text::Parser object.
 
@@ -12,7 +12,7 @@ use Role::Tiny;
 
 
 requires(
-    qw(save_record lines_parsed has_aborted __read_file_handle),
+    qw(save_record setting lines_parsed has_aborted __read_file_handle),
     qw(join_last_line is_line_continued) );
 
 use Exception::Class (
@@ -141,10 +141,18 @@ Text::Parser::Multiline - Adds multi-line support to the Text::Parser object.
 
 =head1 VERSION
 
-version 0.800
+version 0.801
 
 =head1 SYNOPSIS
 
+    use Text::Parser;
+
+    my $parser = Text::Parser->new(multiline_type => 'join_last');
+    $parser->read('filename.txt');
+    print $parser->get_records();
+    print scalar($parser->get_records()), " records were read although ",
+        $parser->lines_parsed(), " lines were parsed.\n";
+
 =head1 RATIONALE
 
 Some text formats allow users to split a single line into multiple lines, with a continuation character in the beginning or in the end, usually to improve human readability.
@@ -193,7 +201,7 @@ To create a multi-line text parser you need to know:
 
 =item *
 
-L<Determine|Text::Parser/new> if your parser is a C<'join_next'> type or a C<'join_last'> type. This depends on which line has the continuation character.
+L<Determine|Text::Parser/new> if your parser is a C<'join_next'> type or a C<'join_last'> type.
 
 =item *
 
@@ -205,6 +213,8 @@ How to strip the continuation character and join with last line
 
 =back
 
+=head1 REQUIRED METHODS
+
 So here are the things you need to do if you have to write a multi-line text parser:
 
 =over 4
@@ -227,27 +237,28 @@ Override the C<join_last_line> to join the previous line and the current line af
 
 =item *
 
-Implement your C<save_record> as if you always get joined lines, and
+Implement your C<save_record> as if you always get joined lines!
 
 =back
 
-=head1 REQUIRED METHODS
+That's it! What's more? There are some default implementations for these methods in L<Text::Parser> class already. But if you want to do any stripping of continuation characters etc., you'd want to override these in your own parser class.
 
-The following methods are required to compose this role into an object or a class. There are some default implementations for both these methods, but for most practical purposes you'd want to override those in your own parser class.
+=head2 C<< Text::Parser->new(%options) >>
 
-=head3 C<$self->E<gt>C<is_line_continued($line)>
+L<Decide|Text::Parser/new> if you want to set any options like C<auto_chomp> by default. In order to get a multi-line parser, you I<must> select one of C<multiline_type> values: C<'join_next'> or C<'join_last'>.
 
-Takes a string argument as input. Returns a boolean that indicates if the current line is continued from the previous line, or is continued on the next line (depending on the type of multi-line text format).
+=head2 C<< $parser->is_line_continued($line) >>
 
-=head2 C<$self->E<gt>C<join_last_line($last_line, $current_line)>
+Takes a string argument as input. Returns a boolean that indicates if the current line is continued from the previous line, or is continued on the next line (depending on the type of multi-line text format). You don't need to bother about how the boolean result of this routine is interpreted. That is handled depending on the type of multi-line parser. The way the result of this function is interpreted depends on the type of multi-line parser you make. If it is a C<'join_next'> parser, then a true value from this routine means that some data is expected to be in the I<next> line which is expected to be joined with this line. If instead the parser is C<'join_last'>, then a true value from this method would mean that the current line is a continuation from the I<previous> line, and the current line should be appended to the content of the previous line.
 
-Takes two string arguments. The first is the line previously read which is expected to be continued on this line. The function should return a string that has stripped any continuation characters, and joined the current line with the previous line.
+=head2 C<< $parser->join_last_line($last_line, $current_line) >>
+
+Takes two string arguments. The first is the line previously read which is expected to be continued on this line. You can be certain that the two strings will not be C<undef>. Your method should return a string that has stripped any continuation characters, and joined the current line with the previous line. You don't need to bother about where and how this is being saved. You also don't need to bother about where the last line is stored/coming from. The management of the last line is handled internally.
 
 =head1 BUGS
 
 Please report any bugs or feature requests on the bugtracker website
-L<http://rt.cpan.org/Public/Dist/Display.html?Name=Text-Parser> or by email
-to L<bug-text-parser at rt.cpan.org|mailto:bug-text-parser at rt.cpan.org>.
+L<http://github.com/me/Text-Parser/issues>
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
